@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 """digitalocean API to manage droplets"""
 
-__version__ = "1.11"
+__version__ = "1.13.2"
 __author__ = "Lorenzo Setale ( http://who.is.lorenzo.setale.me/? )"
-__author_email__ = "koalalorenzo@gmail.com"
+__author_email__ = "lorenzo@setale.me"
 __license__ = "LGPL v3"
-__copyright__ = "Copyright (c) 2012, 2013, 2014 Lorenzo Setale"
+__copyright__ = "Copyright (c) 2012, 2013, 2014, 2015, 2016, 2017, 2018 Lorenzo Setale"
 
 from .Manager import Manager
 from .Droplet import Droplet, DropletError, BadKernelObject, BadSSHKeyFormat
@@ -25,3 +25,5 @@ from .Tag import Tag
 from .LoadBalancer import LoadBalancer
 from .LoadBalancer import StickySesions, ForwardingRule, HealthCheck
 from .Certificate import Certificate
+from .Snapshot import Snapshot
+from .Firewall import Firewall, InboundRule, OutboundRule, Destinations, Sources
